@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: IunoSettings.py 9689 2016-06-24 11:15:35Z Bear $
+# $Id: IunoSettings.py 10274 2017-09-05 09:03:11Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Bear $ (last)
-# $Date: 2016-06-24 19:15:35 +0800 (Fri, 24 Jun 2016) $
-# $Revision: 9689 $
+# $Author: Lavender $ (last)
+# $Date: 2017-09-05 17:03:11 +0800 (週二, 05 九月 2017) $
+# $Revision: 10274 $
 """
 Default settings for this project if it can't import settings.
 """
@@ -74,4 +74,5 @@ INSTALLED_APPS = (
     'Iuppiter.extension',
     'Iuppiter.test',
     'Iuno.tests',
+    'Iuno.scaffold',
 )
