@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 9994 2017-05-28 14:47:33Z David $
+# $Id: __init__.py 10194 2017-08-16 05:53:21Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $ (last)
-# $Date: 2017-05-28 22:47:33 +0800 (Sun, 28 May 2017) $
-# $Revision: 9994 $
+# $Date: 2017-08-16 13:53:21 +0800 (週三, 16 八月 2017) $
+# $Revision: 10194 $
 
 import os
 import sys
@@ -589,6 +589,15 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
     
     update(settingsDict, rootUrlDefaults)
     #=========================================================================
+    
+    #=========================================================================
+    # HTTPS.
+    if 'SECURE_PROXY_SSL_HEADER' not in settingsDict:
+        https = os.environ.get('HTTPS', None)
+        if https == 'on':
+            settingsDict['SECURE_PROXY_SSL_HEADER'] = (
+                'HTTP_X_FORWARDED_PROTO', 'https')
+    #=========================================================================
 
     #=========================================================================
     # WSGI.
@@ -810,6 +819,7 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
 
     #=========================================================================
 
+
 # detect Server mode
 def detectServerMode(settingsDict):
     """
@@ -834,3 +844,4 @@ def detectDebug(settingsDict):
         STAGE, PRODUCTION) else False)
 
     return _DEBUG
+
